Changes
=======
The **release** branch changes this fork of wtforms-alchemy so it can be released under a
different package name, ``marvin-wtforms-alchemy``, in order to accommodate
the `Marvin <https::/github.com/sdss/marvin>`_ release structure.  This release mainly
adds Posgres array and json types as valid options.
See `PR 145 <https://github.com/kvesteri/wtforms-alchemy/pull/145>`_.
If that PR gets merged, this fork can be deprecated.

This repo is maintained at `<https://github.com/havok2063/wtforms-alchemy>`_, with changes
pushed occassionally.

WTForms-Alchemy
===============

|Build Status| |Version Status| |Downloads|

Tools for creating WTForms forms from SQLAlchemy models


Resources
---------

- `Documentation <https://wtforms-alchemy.readthedocs.io/>`_
- `Issue Tracker <http://github.com/kvesteri/wtforms-alchemy/issues>`_
- `Code <http://github.com/kvesteri/wtforms-alchemy/>`_

.. |Build Status| image:: https://travis-ci.org/kvesteri/wtforms-alchemy.png?branch=master
   :target: https://travis-ci.org/kvesteri/wtforms-alchemy
.. |Version Status| image:: https://img.shields.io/pypi/v/WTForms-Alchemy.svg
   :target: https://pypi.python.org/pypi/WTForms-Alchemy/
.. |Downloads| image:: https://img.shields.io/pypi/dm/WTForms-Alchemy.svg
   :target: https://pypi.python.org/pypi/WTForms-Alchemy/
